Array

Struct Array 

pub struct Array<'ducc>(/* private fields */);
Reference to a JavaScript array.

Implementations

Source

impl<'ducc> Array<'ducc>

pub fn into_object(self) -> Object<'ducc>

Consumes the array and returns it as a JavaScript object. This is inexpensive, since an array is an object.

pub fn get<V: FromValue<'ducc>>(&self, index: u32) -> Result<V>

Get the value using the given array index. Returns Value::Undefined if no element at the index exists.

Errors

This function returns an error if:

  • FromValue::from_value fails for the element
pub fn set<V: ToValue<'ducc>>(&self, index: u32, value: V) -> Result<()>

Sets an array element using the given index and value.

Errors

This function returns an error if:

  • ToValue::to_value fails for the value
pub fn len(&self) -> Result<usize>

Returns the number of elements in the array using the calculation Math.floor(ToNumber(array.length)). This function can return an error if the ToNumber implementation fails or if the length getter fails.

pub fn push<V: ToValue<'ducc>>(&self, value: V) -> Result<()>

Pushes an element to the end of the array. This is a shortcut for set using len as the index.

pub fn elements<V: FromValue<'ducc>>(self) -> Elements<'ducc, V>

Returns an iterator over the array’s indexable values.