pub struct Error {
pub kind: ErrorKind,
pub context: Vec<String>,
}Fields
kind: ErrorKindThe underlying type of error.
context: Vec<String>An optional list of context messages describing the error. This corresponds to the
JavaScript Error’s message property.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn external<T: RuntimeError + 'static>(error: T) -> Error
pub fn external<T: RuntimeError + 'static>(error: T) -> Error
Creates an Error from any type that implements RuntimeError.
pub fn from_js_conversion(from: &'static str, to: &'static str) -> Error
pub fn to_js_conversion(from: &'static str, to: &'static str) -> Error
pub fn recursive_mut_callback() -> Error
pub fn not_a_function() -> Error