String

Struct String 

pub struct String<'ducc>(/* private fields */);
An immutable, interned JavaScript string managed by Duktape.

Unlike Rust strings, Duktape strings are CESU-8 (not UTF-8).

Implementations

Source

impl<'ducc> String<'ducc>

pub fn to_string(&self) -> Result<StdString>

Returns a Rust string converted from the Duktape string as long as it can be converted from CESU-8 to UTF-8.

pub fn as_bytes(&self) -> &[u8]

Returns the bytes that make up this string, without a trailing nul byte. This is a CESU-8 string.

pub fn as_bytes_with_nul(&self) -> &[u8]

Returns the bytes that make up this string, including a trailing nul byte. This is a CESU-8 string.